diff --git a/web/pgadmin/browser/server_groups/servers/databases/__init__.py b/web/pgadmin/browser/server_groups/servers/databases/__init__.py
index 4590d6c..8d8133a 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/__init__.py
+++ b/web/pgadmin/browser/server_groups/servers/databases/__init__.py
@@ -301,7 +301,26 @@ class DatabaseView(PGChildNodeView):
 
     @check_precondition(action="get_databases")
     def get_databases(self, gid, sid):
-        res = self.get_nodes(gid, sid, True)
+        """
+        This function is used to get all the databases irrespective of
+        show_system_object flag for templates in create database dialog.
+        :param gid:
+        :param sid:
+        :return:
+        """
+        res = []
+        SQL = render_template(
+            "/".join([self.template_path, 'nodes.sql']),
+            last_system_oid=0,
+        )
+        status, rset = self.conn.execute_dict(SQL)
+
+        if not status:
+            return internal_server_error(errormsg=rset)
+
+        for row in rset['rows']:
+            res.append(row['name'])
+
         return make_json_response(
             data=res,
             status=200
diff --git a/web/pgadmin/browser/server_groups/servers/databases/static/js/database.js b/web/pgadmin/browser/server_groups/servers/databases/static/js/database.js
index 2da27a3..1bb6759 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/static/js/database.js
+++ b/web/pgadmin/browser/server_groups/servers/databases/static/js/database.js
@@ -340,7 +340,7 @@ define('pgadmin.node.database', [
             else {
               if (data && _.isArray(data)) {
                 _.each(data, function(d) {
-                  res.push({label: d.label, value: d.label,
+                  res.push({label: d, value: d,
                     image: 'pg-icon-database'});
                 });
               }
